==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Aurreko orria");
define("_NEXT","Hurrengo orria");

define("_SEARCHRESULTS","Bilaketaren emaitzak");
define("_PAGE","orrialde ");
define("_RETURNTO","Bueltatu hona:");
define("_DEACTIVATE","Desaktibatu");
define("_ACTIVATE","Aktibatu");
define("_ENCYCLOPEDIA","Entziklopedia");
define("_NOCONTENTFORLETTER","Sentitzen dut, ez dago terminorik letra horrekin");
define("_ENCYSELECTLETTER","Aukeratu hizki bat ondorengo zerrendan terminoak kontsultatzeko:");
define("_COPYRIGHT","Kopia-eskubide guztiak $sitename -eko administratzailearenak. Eskubide guztiak erreserbatuta.");
define("_YOURADMINENCY","Administratzailea zara: entziklopedia hau ez dago aktibatuta");
define("_ENCYNOTACTIVE","Entziklopedia hau ez dago aktibatuta");
define("_AVAILABLEENCYLIST","Sistema honetan erabilgarri dauden enziklopedien zerrenda:");
define("_YOURADMININACTIVELIST","Administratzailea zara: ondoren aktibatu gabe dauden entziklopediak");
define("_NORESULTSTEXT","Ez da aurkitu emaitzarik terminoen testuetan...");
define("_NORESULTSTITLE","Ez da aurkitu emaitzarik terminoen tituluetan...");
define("_SEARCHRESULTSFOR","Termino hauen bilaketa emaitza:");
define("_SEARCHNOTCOMPLETE","Bilaketa aukerak errebisatu eta saiatu berriz.");
define("_RESULTSINTERMTITLE","Bilaketaren emaitzak terminoen tituloa kontutan izanik:");
define("_RESULTSINTERMTEXT","Bilaketaren emaitzak terminoen testua kontutan izanik:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Aurreko orria");
define("_NEXT","Hurrengo orria");

define("_SEARCHRESULTS","Bilaketaren emaitzak");
define("_PAGE","orrialde ");
define("_RETURNTO","Bueltatu hona:");
define("_DEACTIVATE","Desaktibatu");
define("_ACTIVATE","Aktibatu");
define("_ENCYCLOPEDIA","Entziklopedia");
define("_NOCONTENTFORLETTER","Sentitzen dut, ez dago terminorik letra horrekin");
define("_ENCYSELECTLETTER","Aukeratu hizki bat ondorengo zerrendan terminoak kontsultatzeko:");
define("_COPYRIGHT","Kopia-eskubide guztiak $sitename -eko administratzailearenak. Eskubide guztiak erreserbatuta.");
define("_YOURADMINENCY","Administratzailea zara: entziklopedia hau ez dago aktibatuta");
define("_ENCYNOTACTIVE","Entziklopedia hau ez dago aktibatuta");
define("_AVAILABLEENCYLIST","Sistema honetan erabilgarri dauden enziklopedien zerrenda:");
define("_YOURADMININACTIVELIST","Administratzailea zara: ondoren aktibatu gabe dauden entziklopediak");
define("_NORESULTSTEXT","Ez da aurkitu emaitzarik terminoen testuetan...");
define("_NORESULTSTITLE","Ez da aurkitu emaitzarik terminoen tituluetan...");
define("_SEARCHRESULTSFOR","Termino hauen bilaketa emaitza:");
define("_SEARCHNOTCOMPLETE","Bilaketa aukerak errebisatu eta saiatu berriz.");
define("_RESULTSINTERMTITLE","Bilaketaren emaitzak terminoen tituloa kontutan izanik:");
define("_RESULTSINTERMTEXT","Bilaketaren emaitzak terminoen testua kontutan izanik:");


?>
